@@ -61,6 +61,7 @@ typedef struct _headerattr
   char* name;
   int   occurence;
   int   direction;
+  int   mandatory;
   char* value;
 } headerAttr_t, headerVal_t;
 
@@ -402,12 +403,10 @@ parsePreBid(memBuf_t *mp, auctionInfo *aip)
 	return ret;
 }
 
-// MSP Oct. 2016
 static const char LOGIN_1_URL[] = "https://%s/ws/eBayISAPI.dll?SignIn";
 static const char LOGIN_2_URL[] = "https://%s/ws/eBayISAPI.dll?co_partnerId=2&siteid=0&UsingSSL=1";
 static const char LOGIN_DATA[] = "refId=&regUrl=%s&MfcISAPICommand=SignInWelcome&bhid=DEF_CI&UsingSSL=1&inputversion=2&lse=false&lsv=&mid=%s&kgver=1&kgupg=1&kgstate=&omid=&hmid=&rhr=f&srt=%s&siteid=0&co_partnerId=2&ru=&pp=&pa1=&pa2=&pa3=&i1=-1&pageType=-1&rtmData=&usid=%s&afbpmName=sess1&kgct=&userid_otp=&sgnBt=Continue&otp=&keepMeSignInOption3=1&userid=%s&%s=%s&runId2=%s&%s=%s&pass=%s&keepMeSignInOption2=1&keepMeSignInOption=1";
 
-// MSP Oct. 2016
 static const char* id="id=\"";
 static const char* id2="value=\"";
 
@@ -420,14 +419,14 @@ static const int SRT=2;
 static const int USID=3;
 static const int RUNID2=4;
 
-static headerAttr_t headerAttrs[] = {"<label for=\"userid\">", 1, 1, NULL,
-                            "\"password\"", 1, -1, NULL};
+static headerAttr_t headerAttrs[] = {"<label for=\"userid\">", 1, 1, 1, NULL,
+                            "\"password\"", 1, -1, 1, NULL};
 
-static headerVal_t headerVals[] = {"regUrl", 1, 1, NULL,
-                           "mid", 1, 1, NULL,
-                           "srt", 1, 1, NULL,
-                           "usid", 1, 1, NULL,
-                           "runId2", 1, 1, NULL};
+static headerVal_t headerVals[] = {"regUrl", 1, 1, 1, NULL,
+                           "mid", 1, 1, 1, NULL,
+                           "srt", 1, 1, 1, NULL,
+                           "usid", 1, 1, 1, NULL,
+                           "runId2", 1, 1, 0, NULL};
 
 static int
 signinFormSearch(char* src, size_t srcLen, headerAttr_t* searchdef, searchType_t searchfor)
@@ -447,7 +446,11 @@ signinFormSearch(char* src, size_t srcLen, headerAttr_t* searchdef, searchType_t
 	for(i = 0; i < searchdef->occurence; i++) {
 		search = strstr(start, pattern);
 		if( search == NULL )
-			return 1;
+		{
+			searchdef->value = (char *)myMalloc(1);
+			strncpy(searchdef->value, "\0", 1);
+			return searchdef->mandatory;
+		}
 		start = search;
 		start += strlen(pattern);
 	}
@@ -471,7 +474,13 @@ signinFormSearch(char* src, size_t srcLen, headerAttr_t* searchdef, searchType_t
 		}
 	}
 
-	return 1;
+	if( searchdef->value == NULL )
+        {
+            searchdef->value = (char *)myMalloc(1);
+            strncpy(searchdef->value, "\0", 1);
+            return searchdef->mandatory;
+        }
+	return searchdef->mandatory;
 }
 
 static int
@@ -534,7 +543,7 @@ ebayLogin(auctionInfo *aip, time_t interval)
 	if (!mp)
 		return httpError(aip);
 
-	// Get all atrributes and values needed (MSP Oct. 2016)
+	// Get all atrributes and values needed
 	for(i = 0; i < sizeof(headerAttrs)/sizeof(headerAttr_t); i++)
 		if(findAttr(mp->memory, mp->size, &headerAttrs[i]))
 			bugReport("ebayLogin", __FILE__, __LINE__, aip, mp, optiontab,
@@ -547,7 +556,6 @@ ebayLogin(auctionInfo *aip, time_t interval)
 	freeMembuf(mp);
 	mp = NULL;
 
-	// MSP Oct. 2016
 	urlLen = sizeof(LOGIN_2_URL) + strlen(options.loginHost) - (1*2);
 	password = getPassword();
 	url = (char *)myMalloc(urlLen);
@@ -602,10 +610,10 @@ ebayLogin(auctionInfo *aip, time_t interval)
 					"*****"
 					);
 
-	// MSP Oct. 2016 - Using POST method instead of GET
+	// Using POST method instead of GET
 	mp = httpPost(url, data, logdata);
 
-	// Free memory (MSP Oct. 2016)
+	// Free memory
 	for(i=0; i < sizeof(headerAttrs)/sizeof(headerAttr_t); free(headerAttrs[i++].value));
 	for(i=0; i < sizeof(headerVals)/sizeof(headerVal_t); free(headerVals[i++].value));
 	free(url);
