@@ -100,16 +100,22 @@ parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t s
 	int auctionResult = 0;
 	int got;
 	const char *delim = "_";
-
-
+	typedef enum phtype { phclassic, ph201702, phunknown } phtype;
+	phtype pagetype = phunknown;
 
 	if ((pp->srcId && !strcmp(pp->srcId, "Captcha.xsl")) ||
 		(pp->pageName && !strncmp(pp->pageName, "Security Measure", 16)))
 		return auctionError(aip, ae_captcha, NULL);
-	if (pp->pageName && !strncmp(pp->pageName, "PageViewBids", 12)) {
+	if (pp->pageName && ( !strncmp(pp->pageName, "PageViewBids", 12) ||
+			      !strncmp(pp->pageName, "eBay Item Bid History", 21) )) {	
 		char *tmpPagename = myStrdup(pp->pageName);
 		char *token;
 
+		if (!strncmp(pp->pageName, "eBay Item Bid History", 21))
+			pagetype = ph201702;
+		else
+			pagetype = phclassic;
+
 		pageType = VIEWBIDS;
 
 		/* this must be PageViewBids */
@@ -162,6 +168,14 @@ parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t s
 			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "no item number");
 			return auctionError(aip, ae_baditem, NULL);
 		}
+	} else if (memStr(mp, "<span>Item number:</span>")) { 
+                line = getNonTag(mp);   /* Item number: */
+                line = getNonTag(mp);   /* number */
+		if (!line) {
+                        log(("parseBidHistory(): No item number"));
+                        bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "no item number");
+                        return auctionError(aip, ae_baditem, NULL);
+		}
 	} else {
 		log(("parseBidHistory(): BHitemNo not found"));
 		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "no item number");
@@ -192,6 +206,23 @@ parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t s
 			bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "item title not found");
 			return auctionError(aip, ae_baditem, NULL);
 		}
+	/* Active auction */
+        } else if (memStr(mp, "<span>Item info</span>")) {
+                line = getNonTag(mp);   /* Item title: */
+                line = getNonTag(mp);   /* title */
+                if (!line) {
+                        log(("parseBidHistory(): No item title"));
+                        bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "item title not found");
+        	}
+	/* Post bid */
+        } else if (memStr(mp, "\"offer-title-top_panel_main\"")) {
+		memChr(mp, '>');
+		memSkip(mp, 1);
+                line = getNonTag(mp);   /* title */
+                if (!line) {
+                        log(("parseBidHistory(): No item title"));
+                        bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "item title not found");
+                }
 	} else {
 		log(("parseBidHistory(): BHitemTitle not found"));
 		bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "item title or description not found");
@@ -271,6 +302,45 @@ parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t s
 		free(aip->remainRaw);
 		aip->remainRaw = myStrdup("--");
 		aip->remain = 0;
+	} else if (memStr(mp, "<span>Time left:</span>")) {
+		char* hours = myMalloc(12);
+		char* minutes = myMalloc(12);
+		char* seconds = myMalloc(12);	
+		char tmpTimeLeft[255];
+		memset(hours, '\0', sizeof(hours));
+		memset(minutes, '\0', sizeof(minutes));
+		memset(seconds, '\0', sizeof(seconds));
+		memset(tmpTimeLeft, '\0', sizeof(tmpTimeLeft));
+
+		if (memStr(mp, "\"_counter_itemEndDate_hour\"")) {
+	                memChr(mp, '>');
+	                memSkip(mp, 1);
+			strncpy(hours, getNonTag(mp), 4);
+		}
+		else
+			strcpy(hours, "0");
+		if (memStr(mp, "\"_counter_itemEndDate_minute\"")) {
+                        memChr(mp, '>');
+                        memSkip(mp, 1);
+			strncpy(minutes, getNonTag(mp), 2);
+		}
+		else
+			strcpy(seconds, "0");
+		if (memStr(mp, "\"_counter_itemEndDate_second\"")) {
+                        memChr(mp, '>');
+                        memSkip(mp, 1);
+			strncpy(seconds , getNonTag(mp), 2);
+		}
+		else
+			strcpy(seconds, "0");
+		sprintf(tmpTimeLeft, "%s hours %s mins %s secs", hours, minutes, seconds);
+		free(hours); free(minutes); free(seconds);
+		aip->remainRaw = myStrdup(tmpTimeLeft);
+ 		aip->remain = getSeconds(tmpTimeLeft);
+                if (aip->remain < 0) {
+                        bugReport("parseBidHistory", __FILE__, __LINE__, aip, mp, optiontab, "remaining time could not be converted (NEW)");
+                        return auctionError(aip, ae_badtime, aip->remainRaw);
+		}
 	} else if (memStr(mp, "timeLeft")) {
 		memChr(mp, '>');
 		memSkip(mp, 1);
@@ -415,8 +485,8 @@ parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t s
 
 		row = getTableRow(mp);
 		ncolumns = numColumns(row);
-		if (ncolumns >= 5) {
-			char *rawHeader = row[1];
+		if ( (pagetype == phclassic && ncolumns >= 5) || (pagetype == ph201702 && ncolumns >= 3) ) {
+			char *rawHeader = (pagetype == phclassic ? row[1] : row[0]);
 			char *header = getNonTagFromString(rawHeader);
 
 			foundHeader = header &&
@@ -471,14 +541,14 @@ parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t s
 		break;
 	    }
 
+	case 4: /* New history version */
 	case 6:	/* purchase or maybe single auction */
 		/* this case is before 5 because we will fall through if we know
 		 * this is a normal auction.
 		 */
 	    if(pageType != VIEWBIDS)
 	    {
-			char *currently = getNonTagFromString(row[2]);
-
+			char *currently = getNonTagFromString((pagetype == phclassic ? row[2] : row[1]));
 			aip->bids = 0;
 			aip->quantityBid = 0;
 			aip->won = 0;
@@ -486,13 +556,13 @@ parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t s
 			/* find your purchase, count number of purchases */
 			/* blank, user, price, quantity, date, blank */
 			for (; row; row = getTableRow(mp)) {
-				if (numColumns(row) == 6) {
-					int quantity = getIntFromString(row[3]);
+				if ( (pagetype == phclassic && numColumns(row) == 6) || (pagetype == ph201702 && numColumns(row) == 4) ) {
+					int quantity = getIntFromString((pagetype == phclassic ? row[3] : row[2]));
 					char *bidder;
 
 					++aip->bids;
 					aip->quantityBid += quantity;
-					bidder = getNonTagFromString(row[1]);
+					bidder = getNonTagFromString((pagetype == phclassic ? row[1] : row[0]));
 					if (!strcasecmp(bidder, options.username))
 						aip->won = aip->winning = quantity;
 					free(bidder);
@@ -520,14 +590,19 @@ parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t s
 			break;
 	    }
 	    /* FALLTHROUGH */
+	case 3: /* New history version */
 	case 5: /* single auction with bids */
 	    {
 		/* blank, user, price, date, blank */
-		char *winner = getNonTagFromString(row[1]);
-		char *currently = getNonTagFromString(row[2]);
+		char *winner = NULL;
+		if (pagetype == phclassic)
+			winner = getNonTagFromString(row[1]);
+		else
+			winner = getNthNonTagFromString(row[0], 1);
+		char *currently = getNonTagFromString((pagetype == phclassic ? row[2] : row[1]));
 
 		if (!strcasecmp(winner, "Member Id:"))
-		   winner = getNthNonTagFromString(row[1], 2);
+		   winner = getNthNonTagFromString((pagetype == phclassic ? row[1] : row[0]), (pagetype == phclassic ? 2 : 1));
 
 		aip->quantityBid = 1;
 
@@ -561,8 +636,12 @@ parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t s
 		if (aip->bids < 0) {
 			int foundStartPrice = 0;
 			for (aip->bids = 1; !foundStartPrice && (row = getTableRow(mp)); ) {
-				if (numColumns(row) == 5) {
-					char *bidder = getNonTagFromString(row[1]);
+				if ( (pagetype == phclassic && numColumns(row) == 5) || (pagetype == ph201702 && numColumns(row) == 3) ) {
+					char *bidder = NULL;
+					if (pagetype == phclassic)
+						bidder = getNonTagFromString(row[1]);
+					else
+						bidder = getNthNonTagFromString(row[0], 1);
 
 					foundStartPrice = !strcmp(bidder, "Starting Price");
 					if (!foundStartPrice)
@@ -572,7 +651,24 @@ parseBidHistoryInternal(pageInfo_t *pp, memBuf_t *mp, auctionInfo *aip, time_t s
 				freeTableRow(row);
 			}
 		}
-		printLog(stdout, "# of bids: %d\n", aip->bids);
+		if (pagetype == phclassic)
+		{
+			printLog(stdout, "# of bids: %d\n", aip->bids);
+		}
+		else
+		{
+			int bids2 = aip->bids;
+			memReset(mp);
+		        if (memStr(mp, "<span>Bids:</span>")) {
+                        	line = getNonTag(mp); /* Bids: */
+                        	line = getNonTag(mp); /* Num. of bids */
+				aip->bids = (int)strtol(line, NULL, 10);
+				printLog(stdout, "# of bids: %d (%d incl. autom. bids)\n", aip->bids, bids2);
+			}
+			else {
+				printLog(stdout, "# of bids: %d (autom. bids included)\n", aip->bids);
+			}
+		}
 
 		/* print high bidder */
 		if (strcasecmp(winner, options.username)) {
